@@ -12,7 +12,7 @@ except ImportError:
     from .win_py31_compat import samefile
 
 
-DEFAULT_DESCRIBE = "git describe --dirty --tags --long --match *.*"
+DEFAULT_DESCRIBE = "git describe --dirty --tags --long --match *.* --first-parent"
 
 
 class GitWorkdir(object):
@@ -65,7 +65,7 @@ class GitWorkdir(object):
 def warn_on_shallow(wd):
     """experimental, may change at any time"""
     if wd.is_shallow():
-        warnings.warn('"%s" is shallow and may cause errors' % (wd.path,))
+        warnings.warn('"{}" is shallow and may cause errors'.format(wd.path))
 
 
 def fetch_on_shallow(wd):
@@ -101,9 +101,12 @@ def parse(
     if pre_parse:
         pre_parse(wd)
 
+    if config.git_describe_command:
+        describe_command = config.git_describe_command
+
     out, unused_err, ret = wd.do_ex(describe_command)
     if ret:
-        # If 'git describe' failed, try to get the information otherwise.
+        # If 'git git_describe_command' failed, try to get the information otherwise.
         rev_node = wd.node()
         dirty = wd.is_dirty()
 
