@@ -1,8 +1,9 @@
 from pkg_resources import iter_entry_points
 
 from .version import _warn_if_setuptools_outdated
-from .utils import do
-from . import get_version
+from .config import Configuration
+from .utils import do, trace_exception
+from . import get_version, _get_version
 
 
 def version_keyword(dist, keyword, value):
@@ -28,3 +29,11 @@ def find_files(path=""):
         if res:
             return res
     return []
+
+
+def infer_version(dist):
+    try:
+        config = Configuration.from_file()
+    except Exception:
+        return trace_exception()
+    dist.metadata.version = _get_version(config)
